@@ -100,6 +100,58 @@ class UserenaSignupModelTests(ProfileTestCase):
         self.failUnlessEqual(len(mail.outbox), 1)
         self.assertEqual(mail.outbox[0].to, [self.user_info['email']])
 
+    def test_plain_email(self):
+        """
+        If HTML emails are disabled, check that outgoing emails are not multipart
+        """
+        userena_settings.USERENA_HTML_EMAIL = False
+        new_user = UserenaSignup.objects.create_user(**self.user_info)
+        self.failUnlessEqual(len(mail.outbox), 1)
+        self.assertEqual(unicode(mail.outbox[0].message()).find("multipart/alternative"),-1)
+
+    def test_html_email(self):
+        """
+        If HTML emails are enabled, check outgoings emails are multipart and
+        that different html and plain text templates are used
+        """
+        userena_settings.USERENA_HTML_EMAIL = True
+        userena_settings.USERENA_USE_PLAIN_TEMPLATE = True
+
+        new_user = UserenaSignup.objects.create_user(**self.user_info)
+
+        # Reset configuration
+        userena_settings.USERENA_HTML_EMAIL = False
+
+        self.failUnlessEqual(len(mail.outbox), 1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("multipart/alternative")>-1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("text/plain")>-1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("text/html")>-1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("<html>")>-1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("<h1>Test message")>-1)
+        self.assertFalse(mail.outbox[0].body.find("# Test message")>-1)
+
+    def test_generated_plain_email(self):
+        """
+        If HTML emails are enabled and plain text template are disabled,
+        check outgoings emails are multipart and that plain text is generated
+        from html body
+        """
+        userena_settings.USERENA_HTML_EMAIL = True
+        userena_settings.USERENA_USE_PLAIN_TEMPLATE = False
+
+        new_user = UserenaSignup.objects.create_user(**self.user_info)
+
+        # Reset configuration
+        userena_settings.USERENA_HTML_EMAIL = False
+        userena_settings.USERENA_USE_PLAIN_TEMPLATE = True
+
+        self.failUnlessEqual(len(mail.outbox), 1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("multipart/alternative")>-1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("text/plain")>-1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("text/html")>-1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("<html>")>-1)
+        self.assertTrue(unicode(mail.outbox[0].message()).find("<h1>Test message")>-1)
+        self.assertTrue(mail.outbox[0].body.find("# Test message")>-1)
 
 class BaseProfileModelTest(ProfileTestCase):
     """ Test the ``BaseProfile`` model """
