@@ -10,6 +10,6 @@ class TestProfile(UserenaBaseProfile):
                                               choices=GENDER_CHOICES,
                                               blank=True,
                                               null=True)
-    website = models.URLField(_('website'), blank=True, verify_exists=True)
+    website = models.URLField(_('website'), blank=True)
     location =  models.CharField(_('location'), max_length=255, blank=True)
     about_me = models.TextField(_('about me'), blank=True)
