@@ -22,7 +22,9 @@ urlpatterns = patterns('',
     url(r'^password/reset/$',
        auth_views.password_reset,
        {'template_name': 'userena/password_reset_form.html',
-        'email_template_name': 'userena/emails/password_reset_message.txt'},
+        'email_template_name': 'userena/emails/password_reset_message.txt',
+        'extra_context': {'without_usernames': userena_settings.USERENA_WITHOUT_USERNAMES}
+        },
        name='userena_password_reset'),
     url(r'^password/reset/done/$',
        auth_views.password_reset_done,
